#define FLT_FILENAME_MAX 	40
#define FLT_RESOLVE	1
#define FLT_DONTRESOLVE 0

void gethostparams(struct hostparams *hp, int *aborted,
                   char *isrc, char *ismask, char *isport,
                   char *idst, char *idmask, char *idport, char *iinex);
void tcpfilterselect(struct filterlist *fl, unsigned int *filtered,
		     int *aborted);
void udpfilterselect(struct filterlist *fl, unsigned int *filtercode,
		     char *filename, int *aborted);
void loadsavedtcpfilter(struct filterlist *fl, int *filtered);
int loadfilter(char *filename, struct filterlist *fl, int resolve);
void savefilter(unsigned int protocol, char *filename, struct filterlist *fl);
void destroyfilter(struct filterlist *fl);
void pickafilter(struct ffnode *files, struct ffnode **fltfile, int *aborted);
int utfilter(struct filterlist *fl, unsigned long source, unsigned long dest,
	     unsigned int sport, unsigned int dport, unsigned int protocol);
int mark_filter_change(int protocol);
void listfileerr(int code);
void clear_flt_tag(int protocol);
